/**
 * A class that provides a wrapper around JavaScript's regular expression functionality,
 * closely mirroring the behavior and features of Go's `regexp` package.  It handles
 * raw strings, Unicode, and provides methods for matching, finding, replacing,
 * splitting, and more.
 * @class
 */
export declare class GoRegex {
    originalPattern: string;
    private flags;
    private re;
    /**
     * Creates a new GoRegex instance.
     * @param {string} pattern The regular expression pattern.  Use backticks (`) for raw strings.
     * @param {string} [flags=""] The flags to use with the regular expression (e.g., "i", "g", "u", "m", "s").
     */
    constructor(pattern: string, flags?: string);
    /**
     * Checks if the string contains a match for the regular expression.
     * @param {string} str The string to search.
     * @returns {boolean} True if the string contains a match, false otherwise.
     */
    matchString(str: string): boolean;
    /**
     * Finds the first match in the string.
     * @param {string} str The string to search.
     * @returns {string} The first match, or an empty string if no match is found.
     */
    findString(str: string): string;
    /**
     * Finds all matches in the string.
     * @param {string} str The string to search.
     * @param {number} [n=-1] The maximum number of matches to return.  If -1 (the default), all matches are returned.
     * @returns {string[]} An array of all matches, or an empty array if no matches are found.
     */
    findAllString(str: string, n?: number): string[];
    /**
     * Replaces all matches in the string with the replacement string.
     * @param {string} str The string to search and replace.
     * @param {string} replacement The replacement string.
     * @returns {string} The string with all matches replaced.
     */
    replaceAllString(str: string, replacement: string): string;
    /**
     * Replaces all matches in the string with the result of the replacer function.
     * @param {string} str The string to search and replace.
     * @param {function} replacerFunc The function to call for each match.  The function should return the replacement string.
     * @returns {string} The string with all matches replaced.
     */
    replaceAllStringFunc(str: string, replacerFunc: (match: string, ...args: any[]) => string): string;
    /**
     * Splits the string into an array of substrings using the regular expression as the delimiter.
     * @param {string} str The string to split.
     * @param {number} [n=-1] The maximum number of substrings to return. If -1 (the default), all substrings are returned.
     * @returns {string[]} An array of substrings.
     */
    split(str: string, n?: number): string[];
    /**
     * Finds the first match and returns the match and its submatches.
     * @param {string} str The string to search.
     * @returns {RegExpExecArray | null} An array containing the full match and its submatches, or null if no match is found.
     */
    findStringSubmatch(str: string): RegExpExecArray | null;
    /**
     * Escapes special regular expression characters in a string.  This is equivalent to Go's `regexp.QuoteMeta`.
     * @param {string} str The string to escape.
     * @returns {string} The escaped string.
     */
    static quoteMeta(str: string): string;
    /**
     * Compiles a regular expression pattern into a GoRegex object.
     * @param {string} pattern The regular expression pattern.
     * @param {string} [flags=""] The flags to use with the regular expression.
     * @returns {GoRegex} A GoRegex object.
     * @throws {Error} If the regular expression pattern is invalid.
     */
    static compile(pattern: string, flags?: string): GoRegex;
    /**
     * Compiles a regular expression pattern into a GoRegex object.  This method will panic (throw an error) if the pattern is invalid.
     * @param {string} pattern The regular expression pattern.
     * @param {string} [flags=""] The flags to use with the regular expression.
     * @returns {GoRegex} A GoRegex object.
     * @throws {Error} If the regular expression pattern is invalid.
     */
    static mustCompile(pattern: string, flags?: string): GoRegex;
}
