/**
 * A class that provides a wrapper around JavaScript's regular expression functionality,
 * closely mirroring the behavior and features of Python's `re` module.  It supports
 * flags, matching, searching, finding all matches, iterating matches, full matching,
 * splitting, and substitution.
 * @class
 */
export declare class PythonRegex {
    private pattern;
    private flags;
    /**
     * Creates a new PythonRegex instance.
     * @param {string} pattern The regular expression pattern.
     * @param {string} [flags=""] The flags to use with the regular expression (e.g., "i", "g", "m", "s", "u").
     */
    constructor(pattern: string, flags?: string);
    /**
     * Compiles the regular expression with optional extra flags.
     * @private
     * @param {string} [extraFlags=""] Additional flags to apply when compiling.
     * @returns {RegExp} A compiled RegExp object.
     */
    private compileRegex;
    /**
     * Attempts to match the pattern at the beginning of the string.
     * @param {string} text The string to match against.
     * @returns {RegExpMatchArray | null} A match array if a match is found at the beginning, otherwise null.
     */
    match(text: string): RegExpMatchArray | null;
    /**
     * Searches the string for the first occurrence of the pattern.
     * @param {string} text The string to search.
     * @returns {RegExpMatchArray | null} A match array if a match is found, otherwise null.
     */
    search(text: string): RegExpMatchArray | null;
    /**
     * Finds all non-overlapping matches of the pattern in the string.
     * @param {string} text The string to search.
     * @returns {string[]} An array of all matches.
     */
    findall(text: string): string[];
    /**
     * Returns an iterator yielding match objects for each match found in the string.
     * @param {string} text The string to search.
     * @yields {RegExpExecArray} A match object (RegExpExecArray) for each match.
     * @returns {IterableIterator<RegExpExecArray>} An iterator yielding match objects.
     */
    finditer(text: string): IterableIterator<RegExpExecArray>;
    /**
     * Attempts to match the entire string against the pattern.
     * @param {string} text The string to match.
     * @returns {RegExpMatchArray | null} A match array if the entire string matches, otherwise null.
     */
    fullmatch(text: string): RegExpMatchArray | null;
    /**
     * Splits the string into a list of substrings, using the pattern as the delimiter.
     * @param {string} text The string to split.
     * @param {number} [maxsplit=-1] The maximum number of splits to perform.
     * @returns {string[]} A list of substrings.
     */
    split(text: string, maxsplit?: number): string[];
    /**
     * Replaces occurrences of the pattern in the string with the replacement string.
     * @param {string} repl The replacement string.
     * @param {string} text The string to perform substitutions on.
     * @param {number} [count=0] The maximum number of replacements to perform.
     * @returns {string} The string with replacements made.
     */
    sub(repl: string, text: string, count?: number): string;
}
