/**
 * A class that provides a wrapper around JavaScript's regular expression functionality,
 * closely mirroring the behavior and features of Rust's `regex` crate. It supports
 * flags, matching, searching, finding all matches, iterating matches, capturing groups,
 * splitting, and substitution.
 * @class
 */
export declare class RustRegex {
    private regex;
    unicode: boolean;
    /**
     * Creates a new RustRegex instance.
     * @param {string} pattern The regular expression pattern.
     * @param {string} [flags=""] The flags to use with the regular expression (e.g., "i", "g", "m", "s", "u").
     */
    constructor(pattern: string, flags?: string);
    /**
     * Creates a new RustRegex instance.
     * @param {string} pattern The regular expression pattern.
     * @returns {RustRegex} A new RustRegex instance.
     */
    static new(pattern: string): RustRegex;
    /**
     * Tests if the pattern matches the string.
     * @param {string} text The string to test.
     * @returns {boolean} True if the pattern matches the string, otherwise false.
     */
    isMatch(text: string): boolean;
    /**
     * Finds the first match of the pattern in the string.
     * @param {string} text The string to search.
     * @returns {string | null} The first match if found, otherwise null.
     */
    find(text: string): string | null;
    /**
     * Finds all matches of the pattern in the string.
     * @param {string} text The string to search.
     * @returns {string[]} An array of all matches.
     */
    findIter(text: string): string[];
    /**
     * Captures groups from the first match of the pattern in the string.
     * @param {string} text The string to search.
     * @returns {(string | undefined)[] | null} An array of captured groups if found, otherwise null.
     */
    captures(text: string): (string | undefined)[] | null;
    /**
     * Captures named groups from the first match of the pattern in the string.
     * @param {string} text The string to search.
     * @returns {{ [name: string]: string | undefined } | null} An object with named groups if found, otherwise null.
     */
    namedCaptures(text: string): {
        [name: string]: string | undefined;
    } | null;
    /**
     * Enables or disables case-insensitive matching.
     * @param {boolean} [enabled=true] Whether to enable case-insensitive matching.
     * @returns {RustRegex} A new RustRegex instance with the updated flag.
     */
    caseInsensitive(enabled?: boolean): RustRegex;
    /**
     * Sets the Unicode flag.
     * @param {boolean} enabled Whether to enable the Unicode flag.
     * @returns {RustRegex} The current RustRegex instance.
     */
    setUnicode(enabled: boolean): RustRegex;
    /**
     * Replaces occurrences of the pattern in the string with the replacement string or function.
     * @param {string} text The string to perform replacements on.
     * @param {string | ((match: string, ...captures: string[]) => string)} replacement The replacement string or function.
     * @returns {string} The string with replacements made.
     */
    replace(text: string, replacement: string | ((match: string, ...captures: string[]) => string)): string;
    /**
     * Replaces the first occurrence of the pattern in the string with the replacement string or function.
     * @param {string} text The string to perform the replacement on.
     * @param {string | ((match: string, ...captures: string[]) => string)} replacement The replacement string or function.
     * @returns {string} The string with the first replacement made.
     */
    replaceOne(text: string, replacement: string | ((match: string, ...captures: string[]) => string)): string;
    /**
     * Splits the string into an array of substrings using the pattern as the delimiter.
     * @param {string} text The string to split.
     * @param {number} [limit] The maximum number of splits to perform.
     * @returns {string[]} An array of substrings.
     */
    split(text: string, limit?: number): string[];
    /**
     * Escapes a string to be used literally in a regex pattern.
     * @param {string} text The string to escape.
     * @returns {string} The escaped string.
     */
    static escape(text: string): string;
    /**
     * Returns the original regex pattern string.
     * @returns {string} The original regex pattern string.
     */
    pattern(): string;
    /**
     * Returns the flags used in the regex pattern.
     * @returns {string} The flags used in the regex pattern.
     */
    flags(): string;
    /**
     * Tests if the regex matches the entire string.
     * @param {string} text The string to test.
     * @returns {boolean} True if the regex matches the entire string, otherwise false.
     */
    isMatchFull(text: string): boolean;
    /**
     * Finds the starting and ending indices of the first match.
     * @param {string} text The string to search.
     * @returns {[number, number] | null} A tuple with the start and end indices of the first match, otherwise null.
     */
    findStartEnd(text: string): [number, number] | null;
    /**
     * Finds the starting and ending indices of all matches.
     * @param {string} text The string to search.
     * @returns {[number, number][]} An array of tuples with the start and end indices of all matches.
     */
    findStartEndIter(text: string): [number, number][];
    /**
     * Iterates over all captures in the string.
     * @param {string} text The string to search.
     * @returns {(string[] | undefined)[]} An array of arrays with captured groups.
     */
    capturesIter(text: string): (string[] | undefined)[];
}
